==> jc-1.4.0.tar.gz: gnu/java/nio/PipeImpl__24SourceChannelImpl.h <==
// public final class gnu.java.nio.PipeImpl$SourceChannelImpl

// class file dependencies
// @dep_class e4fef7e4ad06066a gnu_java_nio_PipeImpl__24SourceChannelImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2a71a1103f7cdc8f java_nio_channels_Pipe__24SourceChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_Pipe__24SourceChannel

#include "java/nio/channels/Pipe__24SourceChannel.h"

#ifndef _JC_gnu_java_nio_PipeImpl__24SourceChannelImpl_H_
#define _JC_gnu_java_nio_PipeImpl__24SourceChannelImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object;

typedef const struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$_init$a269c60b1b74311c(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *, jint);

// Virtual methods
extern jint _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *);
extern void _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$implCloseSelectableChannel$315f020e75eca883(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *);
extern void _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$implConfigureBlocking$a0eca1c8bc794f2a(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, jboolean);
extern jint _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$read$8606b3dd4fae9d79(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *);
extern jlong _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$read$151c5116e3d27717(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *);
extern jlong _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$read$c70b8b87112a1668(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$implCloseSelectableChannel$315f020e75eca883;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$implConfigureBlocking$a0eca1c8bc794f2a;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$read$8606b3dd4fae9d79;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$read$151c5116e3d27717;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$read$c70b8b87112a1668;

// Virtual methods structure
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *);
	void	(*implCloseSelectableChannel$315f020e75eca883)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *);
	void	(*implConfigureBlocking$a0eca1c8bc794f2a)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, jboolean);
	jint	(*read$8606b3dd4fae9d79)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *);
	jlong	(*read$151c5116e3d27717)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *);
	jlong	(*read$c70b8b87112a1668)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SourceChannel$vmethods	java_nio_channels_Pipe__24SourceChannel;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods	gnu_java_nio_PipeImpl__24SourceChannelImpl;
};

// Vtype
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs {
    _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs	gnu_java_nio_PipeImpl__24SourceChannelImpl;
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs	java_nio_channels_Pipe__24SourceChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs {
	jint	native__5ffd;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs	java_nio_channels_Pipe__24SourceChannel;
    _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs	gnu_java_nio_PipeImpl__24SourceChannelImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object {
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype	*vtype;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_PipeImpl__24SourceChannelImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$class_object;

#endif	/* _JC_gnu_java_nio_PipeImpl__24SourceChannelImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/PipeImpl__24SourceChannelImpl.h <==
// public final class gnu.java.nio.PipeImpl$SourceChannelImpl

// class file dependencies
// @dep_class e4fef7e4ad06066a gnu_java_nio_PipeImpl__24SourceChannelImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2a71a1103f7cdc8f java_nio_channels_Pipe__24SourceChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_Pipe__24SourceChannel

#include "java/nio/channels/Pipe__24SourceChannel.h"

#ifndef _JC_gnu_java_nio_PipeImpl__24SourceChannelImpl_H_
#define _JC_gnu_java_nio_PipeImpl__24SourceChannelImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs;
typedef struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object;

typedef const struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable;
typedef const struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$_init$a269c60b1b74311c(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$implCloseSelectableChannel$315f020e75eca883(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$implConfigureBlocking$a0eca1c8bc794f2a(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, jboolean) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$read$8606b3dd4fae9d79(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$read$151c5116e3d27717(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method$read$c70b8b87112a1668(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$implCloseSelectableChannel$315f020e75eca883;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$implConfigureBlocking$a0eca1c8bc794f2a;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$read$8606b3dd4fae9d79;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$read$151c5116e3d27717;
extern _jc_method _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$method_info$read$c70b8b87112a1668;

// Virtual methods structure
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*implCloseSelectableChannel$315f020e75eca883)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*implConfigureBlocking$a0eca1c8bc794f2a)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, jboolean) _JC_JCNI_ATTR;
	jint	(*read$8606b3dd4fae9d79)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
	jlong	(*read$151c5116e3d27717)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	jlong	(*read$c70b8b87112a1668)(_jc_env *, struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object *, struct _jc_object_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SourceChannel$vmethods	java_nio_channels_Pipe__24SourceChannel;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vmethods	gnu_java_nio_PipeImpl__24SourceChannelImpl;
};

// Vtype
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs {
    _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_refs	gnu_java_nio_PipeImpl__24SourceChannelImpl;
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs	java_nio_channels_Pipe__24SourceChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs {
	jint	native__5ffd;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs	java_nio_channels_Pipe__24SourceChannel;
    _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$sub_nonrefs	gnu_java_nio_PipeImpl__24SourceChannelImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$object {
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype	*vtype;
	_jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$vtype _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_PipeImpl__24SourceChannelImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_PipeImpl__24SourceChannelImpl$class_object;

#endif	/* _JC_gnu_java_nio_PipeImpl__24SourceChannelImpl_H_ */
